function[x,t]= EulerImplicit(TestFunction,InitialValue,Start,Finish,Nsteps)
// Resuelve el problema de valores iniciales dx/dt = f(x)
// Utiliza el método Implícito de Euler the Implicit Euler
//
// ENTRADAS
// --------
// InitialValue = condición inicial
// Start        = tiempo inicial
// finish       = tiempo final
// Nsteps       = número de pasos o etapas
//
// SALIDAS
// -------
// x            = vector que contiene la solución para cada valor del tiempo
// t            = vector que contiene los tiempos correspondientes a cada valor de x
//
// Descripción
// -----------
// Utiliza el método Implícito de Euler the Implicit Euler para resolver una ODE de la forma dx/dt=f(x,t). 
// El usuario debe suministrar la function f(x,t) y sr de la forma:
// function [dx/dt] = f(x,t)
// Sus argumentos de entrada son la solución al tiempo t, x(t) y t. 
// Devuelve la derivada de la función x(t)
//
// Requerimientos
// --------------
// fsolve  - comando de Scilab que se utiliza para resolver la ecuación implícita. 
//
x(1) = InitialValue;
t(1) = Start;
xo=x(1);
//
//calculate the time ste
dt = (Finish-Start)/Nsteps;
//
for i = 1:Nsteps
  //solve the implicit equation to get the updated value of x
  //calculate the new value of x and t
  t(i+1) = dt + t(i);
  u=t(i+1);
  deff('[residual] = funToSolve(v)','residual= xo+TestFunction(v,u)*dt-v');
  [z,w]=fsolve(xo,funToSolve);
  x(i+1)=z;
  xo=z;
end
//   
t = t';
x = x';
endfunction
